@@ -1,8 +1,11 @@
+from .augmentations.background_noise import AddBackgroundNoise
 from .augmentations.gain import Gain
+from .augmentations.impulse_response import ApplyImpulseResponse
 from .augmentations.peak_normalization import PeakNormalization
 from .augmentations.polarity_inversion import PolarityInversion
+from .augmentations.shift import Shift
 from .core.composition import Compose
-from .utils.convolution import convolve
 from .utils.config import from_dict, from_yaml
+from .utils.convolution import convolve
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
