@@ -15,7 +15,7 @@ class Gain(BaseWaveformTransform):
     See also https://en.wikipedia.org/wiki/Clipping_(audio)#Digital_clipping
     """
 
-    supports_multichannel = True
+    requires_sample_rate = False
 
     def __init__(
         self,
@@ -24,14 +24,17 @@ class Gain(BaseWaveformTransform):
         mode: str = "per_example",
         p: float = 0.5,
         p_mode: typing.Optional[str] = None,
+        sample_rate: typing.Optional[int] = None,
     ):
-        super().__init__(mode, p, p_mode)
+        super().__init__(mode, p, p_mode, sample_rate)
         self.min_gain_in_db = min_gain_in_db
         self.max_gain_in_db = max_gain_in_db
         if self.min_gain_in_db >= self.max_gain_in_db:
-            raise ValueError("min_gain_in_db must be higher than max_gain_in_db")
+            raise ValueError("max_gain_in_db must be higher than min_gain_in_db")
 
-    def randomize_parameters(self, selected_samples, sample_rate: int):
+    def randomize_parameters(
+        self, selected_samples, sample_rate: typing.Optional[int] = None
+    ):
         distribution = torch.distributions.Uniform(
             low=torch.tensor(
                 self.min_gain_in_db, dtype=torch.float32, device=selected_samples.device
@@ -42,21 +45,13 @@ class Gain(BaseWaveformTransform):
             validate_args=True,
         )
         selected_batch_size = selected_samples.size(0)
-        self.parameters["gain_factors"] = convert_decibels_to_amplitude_ratio(
-            distribution.sample(sample_shape=(selected_batch_size,))
+        self.transform_parameters["gain_factors"] = (
+            convert_decibels_to_amplitude_ratio(
+                distribution.sample(sample_shape=(selected_batch_size,))
+            )
+            .unsqueeze(1)
+            .unsqueeze(1)
         )
 
-    def apply_transform(self, selected_samples, sample_rate: int):
-        num_dimensions = len(selected_samples.shape)
-        if num_dimensions == 1:
-            # TODO: We shouldn't support this
-            gain_factors = self.parameters["gain_factors"]
-        elif num_dimensions == 2:
-            gain_factors = self.parameters["gain_factors"].unsqueeze(1)
-        elif num_dimensions == 3:
-            gain_factors = self.parameters["gain_factors"].unsqueeze(1).unsqueeze(1)
-        else:
-            raise Exception(
-                "Invalid number of dimensions ({}) in input tensor".format(num_dimensions)
-            )
-        return selected_samples * gain_factors
+    def apply_transform(self, selected_samples, sample_rate: typing.Optional[int] = None):
+        return selected_samples * self.transform_parameters["gain_factors"]
